<?php

    /**
     * Enqueue theme specific CSS.
     * 
     * return void
     */

    function nvm_enqueue_theme_css () {

        $csss = array(
            array( 'id' => 'layouts-main',  'file' => '/css/layouts.main.css' ),
            array( 'id' => 'theme-init',    'file' => '/css/style.init.css' ),
            array( 'id' => 'theme-buttons', 'file' => '/css/style.buttons.css' ),
            array( 'id' => 'theme-header',  'file' => '/css/style.header.css' ),
            array( 'id' => 'theme-menu',    'file' => '/css/style.menu.css' ),
            array( 'id' => 'theme-social',  'file' => '/css/style.social.css' ),
            array( 'id' => 'theme-forms',   'file' => '/css/style.forms.css' ),
            array( 'id' => 'theme-main',    'file' => '/css/style.main.css' ),
            array( 'id' => 'theme-footer',  'file' => '/css/style.footer.css' ),
            array( 'id' => 'theme-cookie',  'file' => '/css/style.cookie.css' )
        );

        foreach ( $csss as $css ) {
            wp_enqueue_style( $css['id'],  get_template_directory_uri() . $css['file'],  array(), filemtime( get_template_directory() . $css['file'] ), 'all' );
        }



        // Google fonts enqueues and preconnect. 

        wp_enqueue_style( 'fonts', 'https://fonts.googleapis.com/css?family=Open+Sans:300,300italic,400,400italic,700,700italic&subset=latin,greek', array(), '', 'all' );  ?>

        <link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin />

    <?php }

    add_action( 'wp_enqueue_scripts', 'nvm_enqueue_theme_css', 999 );



    /**
     * Enqueue theme specific Javascript.
     * 
     * return void
     */

    function nvm_enqueue_theme_js () {

        $in_footer = true;

        $jsss = array(
            array( 'id' => 'theme-layouts', 'file' => '/js/layouts.main.js',      'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-map',     'file' => '/js/layouts.map.js',       'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-embeds',  'file' => '/js/functions.embeds.js',  'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-forms',   'file' => '/js/functions.forms.js',   'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-imgload', 'file' => '/js/functions.imgload.js', 'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-search',  'file' => '/js/functions.search.js',  'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-tables',  'file' => '/js/functions.tables.js',  'deps' => array( 'responsiville-run' ), 'place' => $in_footer ),
            array( 'id' => 'theme-main',    'file' => '/js/functions.main.js',    'deps' => array( 'responsiville-run' ), 'place' => $in_footer )
        );

        foreach ( $jsss as $js ) {
            wp_enqueue_script( $js['id'], get_template_directory_uri() . $js['file'], $js['deps'], filemtime( get_template_directory() . $js['file'] ), $js['place'] );
        }



        // If Google maps API key is set then modules (like ACF) will probably need the Google maps script. 

        if ( defined( 'VANILLA_GOOGLE_MAPS_API_KEY' ) ) {
            wp_enqueue_script( 'theme-google-map', 'https://maps.googleapis.com/maps/api/js?key=' . VANILLA_GOOGLE_MAPS_API_KEY, array(), '1', $in_footer );
        }

    }

    add_action( 'wp_enqueue_scripts', 'nvm_enqueue_theme_js', 999 );



    /**
     * Enqueue theme specific CSS for the /wp-admin.
     * 
     * return void
     */
    
    function nvm_enqueue_admin_css () { 

        $csss = array(
            array( 'id' => 'theme-admin',   'file' => '/css/style.admin.css' ),
            array( 'id' => 'layouts-admin', 'file' => '/css/layouts.admin.css' ),
        );

        foreach ( $csss as $css ) {
            wp_enqueue_style( $css['id'],  get_template_directory_uri() . $css['file'],  array(), filemtime( get_template_directory() . $css['file'] ), 'all' );
        }

    }

    add_action( 'admin_head', 'nvm_enqueue_admin_css' );



    /**
     * Enqueue theme specific Javascript for the /wp-admin.
     * 
     * return void
     */
    
    function nvm_enqueue_admin_js () { 

        $in_footer = true;

        $jsss = array(
            array( 'id' => 'functions-admin', 'file' => '/js/functions.admin.js', 'deps' => array( 'jquery' ), 'place' => $in_footer ),
            array( 'id' => 'layouts-admin',   'file' => '/js/layouts.admin.js',   'deps' => array( 'jquery' ), 'place' => $in_footer ),
        );

        foreach ( $jsss as $js ) {
            wp_enqueue_script( $js['id'], get_template_directory_uri() . $js['file'], $js['deps'], filemtime( get_template_directory() . $js['file'] ), $js['place'] );
        }

    }

    add_action( 'admin_head', 'nvm_enqueue_admin_js' );

?>