<?php

    /**
     * Enable the enhanced frontend search in order to take into account custom
     * fields and custom taxonomy terms.
     */

    add_filter( 'vanilla_frontend_search_setup', '__return_true' );



    /**
     * Enhance the default frontend search to take custom fields into account. 
     * 
     * @param array $postmetas The custom post meta keys in which to search. 
     * 
     * @return array The custom post meta keys array enhanced.
     */
    
    function nvm_search_add_postmeta ( $postmetas ) {

        // Check if all or only some post meta should be considered.

        if ( defined( 'VANILLA_SEARCH_IN_ALL_META' ) && VANILLA_SEARCH_IN_ALL_META ) {
            $postmetas []= '*';
        } else {
            // $postmetas []= 'meta_key';
        }

        return $postmetas;

    }
    
    add_filter( 'vanilla_frontend_search_postmeta_keys', 'nvm_search_add_postmeta' );



    /**
     * Enhance default search to take taxonomy term names into account. 
     * 
     * @param array $taxonomies The taxonomy term names in which to search.
     * 
     * @return array The taxonomy term names array enhanced.
     */
    
    function nvm_search_add_taxonomies( $taxonomies ) {

        // $taxonomies[] = 'taxonomy_name';
        
        return $taxonomies;
    }

    add_filter( 'vanilla_frontend_search_taxonomies', 'nvm_search_add_taxonomies' );



    /**
     * Returns the enhanced search form. 
     * 
     * @return void
     */

    function nvm_get_search_form() {
        
        get_template_part( 'inc/templates/search-form' );
        exit;

    }
    
    add_action( 'wp_ajax_nvm_get_search_form',        'nvm_get_search_form' );
    add_action( 'wp_ajax_nopriv_nvm_get_search_form', 'nvm_get_search_form' );

?>