<?php

    // Setup the shortcode buttons you need.

    $shortcode_buttons = array();

    $shortcode_buttons[] = array(
        'name'       => 'button-dashicon',
        'title'      => 'Button with a dashicon',
        'icon'       => 'icon dashicons-email',
        'post_type'  => array( 'portfolio' ),
        'code_start' => '[button-dashicon foo="bar"]',
        'code_end'   => '[/button-dashicon]'
    );

    $shortcode_buttons[] = array(
        'name'       => 'button-text',
        'title'      => 'Button with text only',
        'text'       => 'Button text',
        'post_type'  => array( 'post', 'page', 'portfolio' ),
        'code_start' => '[button-text]',
        'code_end'   => '[/button-text]'
    );

    $shortcode_buttons[] = array(
        'name'       => 'button-image',
        'title'      => 'Button with an image',
        'image'      => get_theme_file_uri( 'img/logo.png' ),
        'post_type'  => array( 'post', 'portfolio' ),
        'code_start' => '[button-image]',
        'code_end'   => '[/button-image]'
    );

    // That's it, you are done!

?>

<?php

    /**
     * Echoes the Javascript necessary to act as a TinyMCE plugin which adds the 
     * required buttons and commands to the editor. It is produced as the result
     * of a /wp-admin AJAX call. 
     */
    
    add_action( 'wp_ajax_nvm_tinymce_shortcode_buttons_echo_js', 'nvm_tinymce_shortcode_buttons_echo_js' );

    function nvm_tinymce_shortcode_buttons_echo_js () {

        global $shortcode_buttons;

        header( 'Content-Type: application/javascript' ); ?>

        jQuery( function () {
        
            tinymce.create('tinymce.plugins.nvm_tinymce_shortcode_buttons', {

                init : function( editor, url ) {

                    <?php foreach ( $shortcode_buttons as $shortcode_button ) : ?>

                        editor.addCommand( '<?php echo 'nvm_button_command' . $shortcode_button['name']; ?>', function() {
                            var selected = this.selection.getContent();
                            var content = '';
                            if ( selected ) {
                                content = '<?php echo $shortcode_button['code_start']; ?>' + selected + '<?php echo $shortcode_button['code_end']; ?>';
                            } else {
                                content = '<?php echo $shortcode_button['code_start']; ?>...<?php echo $shortcode_button['code_end']; ?>';
                            }
                            tinymce.execCommand( 'mceInsertContent', false, content );
                        }, editor );

                        editor.addButton( '<?php echo 'nvm_button_' . $shortcode_button['name']; ?>', {
                            title : '<?php echo $shortcode_button['title']; ?>', 
                            cmd : '<?php echo 'nvm_button_command' . $shortcode_button['name']; ?>',
                            <?php echo isset( $shortcode_button['icon'] )  ? 'icon :  \'' . $shortcode_button['icon']  . '\'' : ''; ?>
                            <?php echo isset( $shortcode_button['text'] )  ? 'text :  \'' . $shortcode_button['text']  . '\'' : ''; ?>
                            <?php echo isset( $shortcode_button['image'] ) ? 'image : \'' . $shortcode_button['image'] . '\'' : ''; ?>
                        });

                    <?php endforeach; ?>

                }

            });

            <?php foreach ( $shortcode_buttons as $shortcode_button ) : ?>
                tinymce.PluginManager.add( '<?php echo 'nvm_button_' . $shortcode_button['name']; ?>', tinymce.plugins.nvm_tinymce_shortcode_buttons );
            <?php endforeach; ?>

        }); <?php

        wp_die();

    }

?>

<?php

    /**
     * Echoes the CSS necessary to style the buttons added to the TinyMCE so
     * that they support Dashicons. It is produced as the result of a /wp-admin
     * AJAX call. 
     */
    
    add_action( 'wp_ajax_nvm_tinymce_shortcode_buttons_echo_css', 'nvm_tinymce_shortcode_buttons_echo_css' );

    function nvm_tinymce_shortcode_buttons_echo_css () {

        header( 'Content-Type: text/css' ); ?>

        i.mce-i-icon {
            font: 400 20px/1 'dashicons';
            vertical-align: middle;
        } 

        i.mce-ico {
            vertical-align: middle;
            background-size: contain;
            background-repeat: no-repeat;
        } <?php

        wp_die();
    }

?>

<?php

    /**
     * Necessary actions, filters and their corresponding functions, in order to
     * register the required TinyMCE buttons and the Javascript plugin that will
     * execute their commands in the /wp-admin.
     */

    add_action( 'admin_head', 'nvm_tinymce_shortcode_buttons_setup' );

    function nvm_tinymce_shortcode_buttons_setup () {

        add_filter( 'mce_buttons_3', 'nvm_tinymce_shortcode_buttons_add_buttons' );
        add_filter( 'mce_external_plugins', 'nvm_tinymce_shortcode_buttons_register_plugin' ); 

        wp_enqueue_style( 'nvm_tinymce_shortcode_buttons-css', admin_url( 'admin-ajax.php?action=nvm_tinymce_shortcode_buttons_echo_css' ) ); 

    }

    function nvm_tinymce_shortcode_buttons_add_buttons ( $buttons ) {

        global $shortcode_buttons;

        $current_screen = get_current_screen();

        if ( $current_screen == NULL ) {
            return;
        }

        foreach ( $shortcode_buttons as $shortcode_button ) {

            if ( in_array( $current_screen->post_type, $shortcode_button['post_type'] ) ) {
                $buttons[] = 'nvm_button_' . $shortcode_button['name'];
            }

        }
        
        return $buttons;

    }

    function nvm_tinymce_shortcode_buttons_register_plugin ( $plugin_array ) {

        global $shortcode_buttons;

        foreach ( $shortcode_buttons as $shortcode_button ) {
            $plugin_array['nvm_button_' . $shortcode_button['name']] = admin_url( 'admin-ajax.php?action=nvm_tinymce_shortcode_buttons_echo_js' );
        }

        return $plugin_array;

    }

?>