<?php

    class NVM_Vanilla_Layout_Posts_List extends NVM_Vanilla_Layout {

        public $classes = array( 'vanilla-layout-posts-list', 'vanilla-layout-text' );
        public $type    = 'automatic';
        public $columns = 3;
        public $posts   = array();

        public function __construct( array $layout_fields=null ) {

            parent::__construct( $layout_fields );

            if ( $layout_fields == null ) {

                $this->type    = get_sub_field( 'type' );
                $this->columns = get_sub_field( 'columns' );

                if ( $this->type == 'automatic' ) {

                    $automatic   = get_sub_field( 'automatic_posts_list' );
                    $args        = array(
                        'post_type'      => $automatic['post_type'],
                        'posts_per_page' => $automatic['count'],
                        'orderby'        => $automatic['order_by'],
                        'order'          => $automatic['order_direction']
                    );
                    if ( $automatic['category'] ) {
                        $args['category__in'] = $automatic['category'];
                    }
                    if ( $automatic['tag'] ) {
                        $args['tag__in'] = $automatic['tag'];
                    }
                    if ( $automatic['portfolio_category'] ) {
                        $args['tax_query'] = array(
                            array(
                                'taxonomy' => 'projects',
                                'field'    => 'ID',
                                'terms'    => $automatic['portfolio_category']
                            ),
                        );
                    }
                    $this->posts = get_posts( $args );

                } elseif ( $this->type == 'handpicked' ) {
                    
                    $this->posts = get_sub_field( 'handpicked_posts_list' )['posts'];

                } elseif ( $this->type == 'current_post_children' ) {
                    
                    global $post;
                    $current_page = get_post( $post->ID );
                    $this->posts  = get_posts(array(
                        'post_type'      => $current_page->post_type,
                        'post_parent'    => $current_page->ID,
                        'exclude'        => $current_page->ID,
                        'posts_per_page' => -1,
                        'orderby'        => 'menu_order',
                        'order'          => 'ASC'
                    ));

                } elseif ( $this->type == 'current_post_siblings' ) {
                    
                    global $post;
                    $current_page = get_post( $post->ID );
                    $this->posts  = get_posts(array(
                        'post_type'      => $current_page->post_type,
                        'post_parent'    => $current_page->post_parent,
                        'exclude'        => array( $current_page->ID ),
                        'posts_per_page' => -1,
                        'orderby'        => 'menu_order',
                        'order'          => 'ASC'
                    ));

                }

            } else {

                $this->type    = $layout_fields['type'];
                $this->columns = $layout_fields['columns'];

                if ( $this->type == 'automatic' ) {

                    $automatic   = $layout_fields['automatic_posts_list'];
                    $args        = array(
                        'post_type'      => $automatic['post_type'],
                        'posts_per_page' => $automatic['count'],
                        'orderby'        => $automatic['order_by'],
                        'order'          => $automatic['order_direction']
                    );
                    if ( $automatic['category'] ) {
                        $args['category__in'] = $automatic['category'];
                    }
                    if ( $automatic['tag'] ) {
                        $args['tag__in'] = $automatic['tag'];
                    }
                    if ( $automatic['portfolio_category'] ) {
                        $args['tax_query'] = array(
                            array(
                                'taxonomy' => 'projects',
                                'field'    => 'ID',
                                'terms'    => $automatic['portfolio_category']
                            ),
                        );
                    }
                    $this->posts = get_posts( $args );

                } elseif ( $this->type == 'handpicked' ) {
                    
                    $this->posts = $layout_fields['handpicked_posts_list']['posts'];

                } elseif ( $this->type == 'current_post_children' ) {

                    global $post;
                    $current_page = get_post( $post->ID );
                    $this->posts  = get_posts(array(
                        'post_type'      => $current_page->post_type,
                        'post_parent'    => $current_page->ID,
                        'exclude'        => $current_page->ID,
                        'posts_per_page' => -1,
                        'orderby'        => 'menu_order',
                        'order'          => 'ASC'
                    ));

                } elseif ( $this->type == 'current_post_siblings' ) {
                    
                    global $post;
                    $current_page = get_post( $post->ID );
                    $this->posts  = get_posts(array(
                        'post_type'      => $current_page->post_type,
                        'post_parent'    => $current_page->post_parent,
                        'exclude'        => array( $current_page->ID ),
                        'posts_per_page' => -1,
                        'orderby'        => 'menu_order',
                        'order'          => 'ASC'
                    ));

                }
                
            }

        }

        public function layout() { ?>
            
            <!--
            ================================================================================
            #
            #   POSTS LIST
            #
            ================================================================================
            --> <?php

            $this->section_start(); ?>

                <?php 
                    switch ( $this->columns ) {
                        case 1:
                            $grouping_classes = '';
                            $column_classes   = 'small-column-100';
                            break;
                        case 2:
                            $grouping_classes = 'tablet-group-2';
                            $column_classes   = 'small-column-100 tablet-column-50';
                            break;
                        case 3:
                            $grouping_classes = 'tablet-group-3';
                            $column_classes   = 'small-column-100 tablet-column-33';
                            break;
                        case 4:
                            $grouping_classes = 'tablet-group-2 laptop-group-4';
                            $column_classes   = 'small-column-100 tablet-column-50 laptop-column-25';
                            break;
                    }
                ?>

                <div class = "panel">

                    <?php $this->section_title(); ?>

                    <div class = "<?php echo $grouping_classes; ?>">
                        <?php global $post; ?>
                        <?php foreach ( $this->posts as $post ) : setup_postdata( $post ); ?>
                            <div class = "vanilla-layout-posts-list-item text <?php echo $column_classes; ?>">
                                <?php 
                                    if ( $this->columns == 1 ) {
                                        get_template_part( 'inc/templates/post-box-horizontal' );
                                    } else {
                                        get_template_part( 'inc/templates/post-box' );
                                    }
                                ?>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <?php wp_reset_postdata(); ?>
                    
                </div> <!-- .panel --> <?php

            $this->section_end();

        }

    }

?>