/**
 * Makes a table responsive by breaking it down into a two-column structure
 * with rows containing a "th" and a "td". In order to achieve this the table
 * must have an equal number of usual table cells (td) and table header cells
 * (th) in all its rows. 
 */

jQuery( function ( $ ) {

    // The Responsiville main object.

    var responsiville = Responsiville.Main.getInstance();



    // Takes all tables marked to be responsive.

    $( '.responsive-table' ).each( function () {

        var table = this;
        responsiville.on( 'change', function () {
            maybeMakeTableResponsive( table );
        });
        maybeMakeTableResponsive( this );

    });



    // Makes them responsive from a specific breakpoint and below.

    function maybeMakeTableResponsive ( table ) {

        // The responsive table.

        var $table = $( table );

        // The responsive table rows.

        var $trs = $table.find( 'tr' );

        // The responsive table headers.

        var $ths = $table.find( 'th' );

        if ( $ths.length == 0 ) {
            $ths = $table.find( 'thead tr:first td' );
            $trs = $table.find( 'tbody tr' );
        }

        if ( $ths.length == 0 ) {
            return;
        }



        if ( responsiville.isBiggerThan( 'tablet' ) ) {

            // Above the given breakpoint show the original table.

            $table.css( 'display', 'table' );

            // And destroy the surrogate table.

            if ( $table.data( 'surrogate' ) ) {
                $table.data( 'surrogate' ).remove();
            }
            
        } else {

            // Below the given breakpoint hide the original table.
            
            $table.css( 'display', 'none' );

            // And create a surrogate table with a two-column layout.

            var tableHTML = '<table>';

            for ( var k=0, length1=$trs.length; k<length1; k++ ) {

                var $tr = $trs.eq( k );

                if ( $tr.find( 'th' ).length > 0 ) {
                    continue;
                }

                var $tds = $tr.find( 'td' );
                for ( var m=0, length2=$tds.length; m<length2; m++ ) {
                    var $td = $tds.eq( m );
                    if ( m == 0 ) {
                        tableHTML += '<thead>';
                    } else if ( m == 1 ) {
                        tableHTML += '<tbody>';
                    }
                    tableHTML += '<tr>';
                    tableHTML += '<th style="width: 20%;">' + $ths.eq( m ).html() + '</th>';
                    tableHTML += '<td>' + $td.html() + '</td>';
                    tableHTML += '</tr>';
                    if ( m == 0 ) {
                        tableHTML += '</thead>';
                    } else if ( m == length2-1 ) {
                        tableHTML += '</tbody>';
                    }
                }

            }

            tableHTML += '</table>';

            var $surrogate = $( tableHTML ).insertBefore( $table );
            $table.data( 'surrogate', $surrogate );

        }

    }

});