/**
 * Fixes pertaining to the layouts admin behaviour.
 */

 jQuery( function ( $ ) {

    // Only care for pages where the TinyMCE editor is defined.

    if ( typeof tinymce === 'undefined' ) {
        return;
    }



    // Prefix of HTML elements that contain TinyMCE editors definde by ACF.

    var ACF_TINYMCE_ID_PREFIX = 'acf-editor-';



    // Lightweight debounce function.

    function nvm_function_debounce ( function_to_debounce, delay, context ) {

        var handler = null;
        var delay   = typeof delay === 'undefined' ? 250 : delay;

        return function () {

            var context = typeof context === 'undefined' ? this : context;
            var args    = arguments;

            clearTimeout( handler );

            handler = setTimeout( function () {
                function_to_debounce.apply( context, args );
            }, delay );

        };

    };



    // Sets the outer editor height to be same as the editor contents height.

    function nvm_fix_editor_height ( editor ) {

        var $iframe = $( editor.iframeElement );

        if ( $iframe.length == 0 ) {
            return;
        }

        var $body = $( $iframe.get( 0 ).contentDocument.documentElement );
        var height = $body.outerHeight( true );
        
        $iframe.css( 'height', height + 'px' );

    };

    // Get hold of a debounced version of the above function.

    var nvm_fix_editor_height_debounced = nvm_function_debounce( nvm_fix_editor_height );



    // Fix editor height when it initialises and when its contents change.

    var editors = [];

    tinymce.on( 'SetupEditor', function ( event ) {

        var editor = event.editor;

        if ( editor.id.indexOf( ACF_TINYMCE_ID_PREFIX ) < 0 ) {
            return;
        }

        editors.push( editor );

        editor.on( 'init', function ( event ) {
            nvm_fix_editor_height( editor );
        });

        editor.on( 'change', function ( event ) {
            nvm_fix_editor_height_debounced( editor );
        });

    });



    // Also fix editor height on window resize.

    $( window ).on( 'resize', function () {
    
        for ( var k=0, length=editors.length; k<length; k++ ) {
            nvm_fix_editor_height_debounced( editors[k] );
        }
        
    });
    
});