/**
 * Layout maps via Google maps.
 */

jQuery( function ( $ ) {

    $( '.vanilla-layout-map' ).each( function () {

        var $layout       = $( this );
        var $points       = $layout.find( '.vanilla-layout-map-point' );
        var $mapElement   = $layout.find( '.vanilla-layout-map-element' );
        var responsiville = Responsiville.Main.getInstance();

        var mapTypes = {
            road       : google.maps.MapTypeId.ROAD,
            satellite  : google.maps.MapTypeId.SATELLITE,
            terrain    : google.maps.MapTypeId.TERRAIN,
            hybrid     : google.maps.MapTypeId.HYBRID,
            styled_map : 'styled_map'
        };



        // Initial map declaration.
    
        var map = new google.maps.Map( $mapElement.get( 0 ), {
            zoom              : 6,
            center            : new google.maps.LatLng( 37, 24 ),
            mapTypeControl    : false,
            streetViewControl : false,
            mapTypeId         : mapTypes[$mapElement.data( 'map-type' )], 
            mapTypeControlOptions : {
                mapTypeIds : ['roadmap', 'satellite', 'hybrid', 'terrain', 'styled_map']
            }
        });

        map.markers = [];
        


        // Custom map styling via Snazzy maps and minified via https://codebeautify.org/jsonminifier.

        var SNAZZY_MAPS_STYLES = [{"featureType":"water","elementType":"geometry","stylers":[{"color":"#e9e9e9"},{"lightness":17}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":20}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#ffffff"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":16}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":21}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#dedede"},{"lightness":21}]},{"elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#ffffff"},{"lightness":16}]},{"elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#333333"},{"lightness":40}]},{"elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#f2f2f2"},{"lightness":19}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#fefefe"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#fefefe"},{"lightness":17},{"weight":1.2}]}];
        
        var styledMapType = new google.maps.StyledMapType( SNAZZY_MAPS_STYLES, { name: 'Styled Map' } );
        map.mapTypes.set( 'styled_map', styledMapType );
        map.setMapTypeId( 'styled_map' );



        // Map points creation. 

        for ( var k=0; k<$points.length; k++ ) {

            var $point = $points.eq( k );
            var latlng = new google.maps.LatLng( $point.data( 'lat' ), $point.data( 'lng' ) );
            var marker = new google.maps.Marker({
                position : latlng,
                map      : map
            });

            // Map point info window.

            var title   = $.trim( $point.find( '.vanilla-layout-map-point-title' ).html() );
            var content = $.trim( $point.find( '.vanilla-layout-map-point-content' ).html() );

            if ( title || content ) {

                var infoWindow = new google.maps.InfoWindow({
                    maxWidth : responsiville.isEqualOrBiggerThan( 'laptop' ) ? 400 : 240,
                    content  : ( title ? '<p class = "gm-style-iw-title"><strong>' + title + '</strong></p>': '' ) + ( content ? content : '' )
                });

                // Memorise info window of marker internally is custom but necessary.

                marker.infoWindow = infoWindow;

                // Open info window on marker click.

                google.maps.event.addListener( marker, 'click', function () {

                    if ( typeof this.infoWindow === 'undefined' ) {
                        return;
                    }

                    for ( var m=0; m<map.markers.length; m++ ) {
                        if ( typeof map.markers[m].infoWindow === 'undefined' ) {
                            continue;
                        }
                        map.markers[m].infoWindow.close();
                    }
                    
                    this.infoWindow.open( map, this );

                });

            }

            map.markers.push( marker );

        }



        // Close all info windows on map click.

        google.maps.event.addListener( map, 'click', function () {
            
            for ( var m=0; m<map.markers.length; m++ ) {
                if ( typeof map.markers[m].infoWindow === 'undefined' ) {
                    continue;
                }
                map.markers[m].infoWindow.close();
            }

        });



        // Recalculate all info windows on resize.

        responsiville.on( 'resize', function () {

            for ( var m=0; m<map.markers.length; m++ ) {

                if ( typeof map.markers[m].infoWindow === 'undefined' ) {
                    continue;
                }

                map.markers[m].infoWindow.close();
                map.markers[m].infoWindow.setOptions({ 
                    maxWidth : responsiville.isEqualOrBiggerThan( 'laptop' ) ? 400 : 240 
                })

            }

        });



        // Center map according to current points.

        var bounds = new google.maps.LatLngBounds();

        $.each( map.markers, function ( k, marker ) {
        
            var latlng = new google.maps.LatLng( marker.position.lat(), marker.position.lng() );
            bounds.extend( latlng );
        
        });



        // Set map zoom level.

        if ( $mapElement.data( 'auto-zoom' ) ) {

            map.fitBounds( bounds );

        } else {

            map.setCenter( bounds.getCenter() );
            map.setZoom( $mapElement.data( 'zoom-level' ) );

            google.maps.event.addListenerOnce( map, 'bounds_changed', function ( event ) {
                map.setZoom( $mapElement.data( 'zoom-level' ) );
            });

        }

    });

});